@@ -1,10 +1,8 @@
 # !/usr/bin/env python3
 
-__version__="0.0.8"
+__version__="0.0.9"
 
-import argparse
-import urllib.request
-from os.path import basename
+import argparse, json, os.path, urllib.request
 from tqdm import tqdm
 
 def get_file_size(url):
@@ -15,7 +13,7 @@ def get_file_size(url):
 def clone_file(url):
     try:
         file_size = get_file_size(url)
-        filename = basename(url)
+        filename = os.path.basename(url)
         # Download the file with progress
         with urllib.request.urlopen(url) as response, \
              open(filename, 'wb') as file, \
@@ -28,10 +26,37 @@ def clone_file(url):
                     break
                 file.write(chunk)
                 pbar.update(len(chunk))
-        print(f"\nFile cloned successfully and saved as '{filename}' in the current directory.")
+        print(f"File cloned successfully and saved as '{filename}' in the current directory.")
     except Exception as e:
         print(f"Error: {e}")
 
+def read_json_file(file_path):
+    response = urllib.request.urlopen(file_path)
+    data = json.loads(response.read())
+    # with open(file_path, 'r') as file:
+        # data = json.load(file)
+    return data
+
+def extract_names(data):
+    for idx, entry in enumerate(data, start=1):
+        print(f'{idx}. {entry["name"]}')
+
+def handle_user_input(data):
+    while True:
+        user_choice = input(f"Enter your choice (1 to {len(data)}) or 'q' to quit: ")
+        if user_choice.lower() == 'q':
+            break
+        try:
+            index = int(user_choice)
+            if 1 <= index <= len(data):
+                source_url = data[index - 1]["url"]
+                clone_file(source_url)
+                break
+            else:
+                print("Invalid selection. Please enter a valid number.")
+        except ValueError:
+            print("Invalid input. Please enter a number.")
+
 def __init__():
     parser = argparse.ArgumentParser(description="cgg will execute different functions based on command-line arguments")
     parser.add_argument('-v', '--version', action='version', version='%(prog)s ' + __version__)
@@ -52,7 +77,13 @@ def __init__():
     if args.subcommand == 'clone':
         clone_file(args.url)
     elif args.subcommand == 's':
-        from gguf_connector import download
+        ## from gguf_connector import download
+        file_path = "https://raw.githubusercontent.com/calcuis/gguf-connector/main/src/gguf_connector/data.json"
+        # file_path = os.path.join(os.path.dirname(__file__), 'data.json')
+        json_data = read_json_file(file_path)
+        print("Please select a GGUF file to download:")
+        extract_names(json_data)
+        handle_user_input(json_data)
     elif args.subcommand == 'menu':
         from gguf_connector import menu
     elif args.subcommand == 'cpp':
